pub enum StorageNewSubCommand {
Local {
path: PathBuf,
name: String,
},
Generic {
name: String,
init_command: String,
list_command: String,
download_command: String,
upload_command: String,
delete_command: String,
max_processes: usize,
url: Option<String>,
storage_dir: Option<String>,
},
Rsync {
name: String,
host: String,
port: Option<usize>,
user: Option<String>,
storage_dir: String,
},
S3 {
name: String,
storage_prefix: String,
bucket_name: String,
region: String,
},
Minio {
name: String,
endpoint: String,
bucket_name: String,
region: String,
storage_prefix: String,
},
DigitalOcean {
name: String,
bucket_name: String,
region: String,
storage_prefix: String,
},
R2 {
name: String,
account_id: String,
bucket_name: String,
storage_prefix: String,
},
Gcs {
name: String,
bucket_name: String,
region: String,
storage_prefix: String,
},
Wasabi {
name: String,
bucket_name: String,
endpoint: String,
storage_prefix: String,
},
}Expand description
Add a new storage
Variants
Local
Add a new local storage
A local storage is a directory accessible from the local file system. Xvc will use common file operations for this directory without accessing the network.
Fields
Generic
Add a new generic storage.
⚠️ Please note that this is an advanced method to configure storages. You may damage your repository and local and storage files with incorrect configurations.
Please see https://docs.xvc.dev/ref/xvc-storage-new-generic.html for examples and make necessary backups.
Fields
init_command: StringCommand to initialize the storage. This command is run once after defining the storage.
You can use {URL} and {STORAGE_DIR} as shortcuts.
list_command: StringCommand to list the files in storage
You can use {URL} and {STORAGE_DIR} placeholders and define values for these with –url and –storage_dir options.
download_command: StringCommand to download a file from storage.
You can use {URL} and {STORAGE_DIR} placeholders and define values for these with –url and –storage_dir options.
upload_command: StringCommand to upload a file to storage.
You can use {URL} and {STORAGE_DIR} placeholders and define values for these with –url and –storage_dir options.
Rsync
Add a new rsync storages
Uses rsync in separate processes to communicate. This can be used when you already have an SSH/Rsync connection. It doesn’t prompt for any passwords. The connection must be set up with ssh keys beforehand.
Fields
port: Option<usize>Port number for the connection in the form 22. Doesn’t add port number to connection string if not given.
S3
Add a new S3 storage
Reads credentials from AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.
Fields
Minio
Add a new Minio storage
Reads credentials from MINIO_ACCESS_KEY and MINIO_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.
Fields
DigitalOcean
Add a new Digital Ocean storage
Reads credentials from DIGITAL_OCEAN_ACCESS_KEY_ID and DIGITAL_OCEAN_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.
Fields
R2
Add a new R2 storage
Reads credentials from R2_ACCESS_KEY_ID and R2_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.
Fields
Gcs
Add a new Google Cloud Storage storage
Reads credentials from GCS_ACCESS_KEY_ID and GCS_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.
Fields
Wasabi
Add a new Wasabi storage
Reads credentials from WASABI_ACCESS_KEY_ID and WASABI_SECRET_ACCESS_KEY environment variables.
Alternatively you can use XVC_STORAGE_ACCESS_KEY_ID_<storage_name> and
XVC_STORAGE_SECRET_ACCESS_KEY_<storage_name> environment variables if you have multiple storages of this type.