pub enum XvcStorage {
Local(XvcLocalStorage),
Generic(XvcGenericStorage),
Rsync(XvcRsyncStorage),
S3(XvcS3Storage),
R2(XvcR2Storage),
Gcs(XvcGcsStorage),
Minio(XvcMinioStorage),
Wasabi(XvcWasabiStorage),
DigitalOcean(XvcDigitalOceanStorage),
}Expand description
A storage that can be used to send and receive files with several different backends
Variants
Local(XvcLocalStorage)
A local storage is a directory that is on the same machine as the repository.
Generic(XvcGenericStorage)
A generic storage creates the storage and sends, receives, deletes files with shell commands
Rsync(XvcRsyncStorage)
A rsync storage is a directory in an Rsync/SSH host
S3(XvcS3Storage)
An S3 storage is a bucket in AWS S3
R2(XvcR2Storage)
An R2 storage is a bucket in R2
Gcs(XvcGcsStorage)
A GCS storage is a bucket in Google Cloud Storage
Minio(XvcMinioStorage)
A Minio storage is a bucket in Minio
Wasabi(XvcWasabiStorage)
A Wasabi storage is a bucket in Wasabi
DigitalOcean(XvcDigitalOceanStorage)
A DigitalOcean storage is a bucket in DigitalOcean