Struct xvc_storage::storage::local::XvcLocalStorage
source · pub struct XvcLocalStorage {
pub guid: XvcStorageGuid,
pub name: String,
pub path: PathBuf,
}Fields
guid: XvcStorageGuidname: Stringpath: PathBufTrait Implementations
sourceimpl Clone for XvcLocalStorage
impl Clone for XvcLocalStorage
sourcefn clone(&self) -> XvcLocalStorage
fn clone(&self) -> XvcLocalStorage
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for XvcLocalStorage
impl Debug for XvcLocalStorage
sourceimpl<'de> Deserialize<'de> for XvcLocalStorage
impl<'de> Deserialize<'de> for XvcLocalStorage
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for XvcLocalStorage
impl Ord for XvcLocalStorage
sourcefn cmp(&self, other: &XvcLocalStorage) -> Ordering
fn cmp(&self, other: &XvcLocalStorage) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<XvcLocalStorage> for XvcLocalStorage
impl PartialEq<XvcLocalStorage> for XvcLocalStorage
sourcefn eq(&self, other: &XvcLocalStorage) -> bool
fn eq(&self, other: &XvcLocalStorage) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<XvcLocalStorage> for XvcLocalStorage
impl PartialOrd<XvcLocalStorage> for XvcLocalStorage
sourcefn partial_cmp(&self, other: &XvcLocalStorage) -> Option<Ordering>
fn partial_cmp(&self, other: &XvcLocalStorage) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for XvcLocalStorage
impl Serialize for XvcLocalStorage
sourceimpl XvcStorageOperations for XvcLocalStorage
impl XvcStorageOperations for XvcLocalStorage
fn init(
self,
output: &Sender<XvcOutputLine>,
xvc_root: &XvcRoot
) -> Result<(XvcStorageInitEvent, Self)>
fn list(
&self,
output: &Sender<XvcOutputLine>,
xvc_root: &XvcRoot
) -> Result<XvcStorageListEvent>
fn send(
&self,
output: &Sender<XvcOutputLine>,
xvc_root: &XvcRoot,
paths: &[XvcCachePath],
force: bool
) -> Result<XvcStorageSendEvent>
fn receive(
&self,
output: &Sender<XvcOutputLine>,
xvc_root: &XvcRoot,
paths: &[XvcCachePath],
force: bool
) -> Result<(XvcStorageTempDir, XvcStorageReceiveEvent)>
fn delete(
&self,
output: &Sender<XvcOutputLine>,
xvc_root: &XvcRoot,
paths: &[XvcCachePath]
) -> Result<XvcStorageDeleteEvent>
impl Eq for XvcLocalStorage
impl StructuralEq for XvcLocalStorage
impl StructuralPartialEq for XvcLocalStorage