pub enum StorageNewSubCommand {
Local {
path: PathBuf,
name: String,
},
Generic {
name: String,
init_command: String,
list_command: String,
download_command: String,
upload_command: String,
delete_command: String,
max_processes: usize,
url: Option<String>,
storage_dir: Option<String>,
},
Rsync {
name: String,
host: String,
port: Option<usize>,
user: Option<String>,
storage_dir: String,
},
S3 {
name: String,
remote_prefix: String,
bucket_name: String,
region: String,
},
Minio {
name: String,
endpoint: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
DigitalOcean {
name: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
R2 {
name: String,
account_id: String,
bucket_name: String,
remote_prefix: String,
},
Gcs {
name: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
Wasabi {
name: String,
bucket_name: String,
endpoint: String,
storage_prefix: String,
},
}Expand description
Add new remotes
Variants
Local
add a new local remote
Generic
Fields
init_command: StringCommand to initialize the remote. This command is run once after defining the remote.
You can use {URL} and {DIR} as shortcuts.
list_command: StringCommand to list the files in remote
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
download_command: StringCommand to download a file from remote.
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
upload_command: StringCommand to upload a file to remote.
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
add a new generic remote
Rsync
Fields
port: Option<usize>Port number for the connection in the form 22. Doesn’t add port number to connection string if not given.
add a new rsync remote
S3
Fields
Add a new S3 remote
Minio
Fields
Add a new Minio remote
DigitalOcean
Fields
Add a new Digital Ocean remote
R2
Fields
Add a new R2 remote
Gcs
Fields
Add a new Google Cloud Storage remote
Wasabi
Fields
Add a new Wasabi remote