pub enum StorageNewSubCommand {
    Local {
        path: PathBuf,
        name: String,
    },
    Generic {
        name: String,
        init_command: String,
        list_command: String,
        download_command: String,
        upload_command: String,
        delete_command: String,
        max_processes: usize,
        url: Option<String>,
        storage_dir: Option<String>,
    },
    S3 {
        name: String,
        remote_prefix: String,
        bucket_name: String,
        region: String,
    },
    Minio {
        name: String,
        endpoint: String,
        bucket_name: String,
        region: String,
        remote_prefix: String,
    },
    DigitalOcean {
        name: String,
        bucket_name: String,
        region: String,
        remote_prefix: String,
    },
    R2 {
        name: String,
        account_id: String,
        bucket_name: String,
        remote_prefix: String,
    },
    Gcs {
        name: String,
        bucket_name: String,
        region: String,
        remote_prefix: String,
    },
    Wasabi {
        name: String,
        bucket_name: String,
        region: String,
        remote_prefix: String,
    },
}
Add new remotes

Variants

Local

Fields

path: PathBuf

Directory to be set as a remote

name: String

add a new local remote

Generic

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

init_command: String

Command to initialize the remote. This command is run once after defining the remote.

You can use {URL} and {DIR} as shortcuts.

list_command: String

Command to list the files in remote

You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.

download_command: String

Command to download a file from remote.

You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.

upload_command: String

Command to upload a file to remote.

You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.

delete_command: String

The delete command to remove a file from remote You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.

max_processes: usize

Number of maximum processes to run simultaneously

url: Option<String>

You can set a string to replace {URL} placeholder in commands

storage_dir: Option<String>

You can set a string to replace {DIR} placeholder in commands

add a new generic remote

S3

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

remote_prefix: String

You can set a directory in the bucket with this prefix

bucket_name: String

S3 bucket name

region: String

AWS region

Add a new S3 remote

Minio

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

endpoint: String

Minio server url in the form https://myserver.example.com:9090

bucket_name: String

Bucket name

region: String

Region of the server

remote_prefix: String

You can set a directory in the bucket with this prefix

Add a new Minio remote

DigitalOcean

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

bucket_name: String

Bucket name

region: String

Region of the server

remote_prefix: String

You can set a directory in the bucket with this prefix

Add a new Digital Ocean remote

R2

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

account_id: String

R2 account ID

bucket_name: String

Bucket name

remote_prefix: String

You can set a directory in the bucket with this prefix

Add a new R2 remote

Gcs

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

bucket_name: String

Bucket name

region: String

Region of the server

remote_prefix: String

You can set a directory in the bucket with this prefix

Add a new Google Cloud Storage remote

Wasabi

Fields

name: String

Name of the remote

This must be unique among all remotes of the project

bucket_name: String

Bucket name

region: String

Region of the server

remote_prefix: String

You can set a directory in the bucket with this prefix

Add a new Wasabi remote