Enum xvc_storage::StorageNewSubCommand
source · [−]pub enum StorageNewSubCommand {
Local {
path: PathBuf,
name: String,
},
Generic {
name: String,
init_command: String,
list_command: String,
download_command: String,
upload_command: String,
delete_command: String,
max_processes: usize,
url: Option<String>,
storage_dir: Option<String>,
},
S3 {
name: String,
remote_prefix: String,
bucket_name: String,
region: String,
},
Minio {
name: String,
endpoint: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
DigitalOcean {
name: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
R2 {
name: String,
account_id: String,
bucket_name: String,
remote_prefix: String,
},
Gcs {
name: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
Wasabi {
name: String,
bucket_name: String,
region: String,
remote_prefix: String,
},
}Expand description
Add new remotes
Variants
Local
add a new local remote
Generic
Fields
name: StringName of the remote
This must be unique among all remotes of the project
init_command: StringCommand to initialize the remote. This command is run once after defining the remote.
You can use {URL} and {DIR} as shortcuts.
list_command: StringCommand to list the files in remote
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
download_command: StringCommand to download a file from remote.
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
upload_command: StringCommand to upload a file to remote.
You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
delete_command: StringThe delete command to remove a file from remote You can use {URL} and {DIR} placeholders and define values for these with –url and –dir options.
max_processes: usizeNumber of maximum processes to run simultaneously
add a new generic remote
S3
Fields
name: StringName of the remote
This must be unique among all remotes of the project
remote_prefix: StringYou can set a directory in the bucket with this prefix
bucket_name: StringS3 bucket name
region: StringAWS region
Add a new S3 remote
Minio
Fields
name: StringName of the remote
This must be unique among all remotes of the project
endpoint: StringMinio server url in the form https://myserver.example.com:9090
bucket_name: StringBucket name
region: StringRegion of the server
remote_prefix: StringYou can set a directory in the bucket with this prefix
Add a new Minio remote
DigitalOcean
Fields
name: StringName of the remote
This must be unique among all remotes of the project
bucket_name: StringBucket name
region: StringRegion of the server
remote_prefix: StringYou can set a directory in the bucket with this prefix
Add a new Digital Ocean remote
R2
Fields
name: StringName of the remote
This must be unique among all remotes of the project
account_id: StringR2 account ID
bucket_name: StringBucket name
remote_prefix: StringYou can set a directory in the bucket with this prefix
Add a new R2 remote
Gcs
Fields
name: StringName of the remote
This must be unique among all remotes of the project
bucket_name: StringBucket name
region: StringRegion of the server
remote_prefix: StringYou can set a directory in the bucket with this prefix
Add a new Google Cloud Storage remote
Wasabi
Fields
name: StringName of the remote
This must be unique among all remotes of the project
bucket_name: StringBucket name
region: StringRegion of the server
remote_prefix: StringYou can set a directory in the bucket with this prefix
Add a new Wasabi remote